# This file was automatically generated by SWIG (https://www.swig.org).
# Version 4.1.1
#
# Do not make changes to this file unless you know what you are doing - modify
# the SWIG interface file instead.

from sys import version_info as _swig_python_version_info
# Import the low-level C/C++ module
if __package__ or "." in __name__:
    from . import _medfile
else:
    import _medfile

try:
    import builtins as __builtin__
except ImportError:
    import __builtin__

def _swig_repr(self):
    try:
        strthis = "proxy of " + self.this.__repr__()
    except __builtin__.Exception:
        strthis = ""
    return "<%s.%s; %s >" % (self.__class__.__module__, self.__class__.__name__, strthis,)


def _swig_setattr_nondynamic_instance_variable(set):
    def set_instance_attr(self, name, value):
        if name == "this":
            set(self, name, value)
        elif name == "thisown":
            self.this.own(value)
        elif hasattr(self, name) and isinstance(getattr(type(self), name), property):
            set(self, name, value)
        else:
            raise AttributeError("You cannot add instance attributes to %s" % self)
    return set_instance_attr


def _swig_setattr_nondynamic_class_variable(set):
    def set_class_attr(cls, name, value):
        if hasattr(cls, name) and not isinstance(getattr(cls, name), property):
            set(cls, name, value)
        else:
            raise AttributeError("You cannot add class attributes to %s" % cls)
    return set_class_attr


def _swig_add_metaclass(metaclass):
    """Class decorator for adding a metaclass to a SWIG wrapped class - a slimmed down version of six.add_metaclass"""
    def wrapper(cls):
        return metaclass(cls.__name__, cls.__bases__, cls.__dict__.copy())
    return wrapper


class _SwigNonDynamicMeta(type):
    """Meta class to enforce nondynamic attributes (no new attributes) for a class"""
    __setattr__ = _swig_setattr_nondynamic_class_variable(type.__setattr__)


class SwigPyIterator_medfile(object):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")

    def __init__(self, *args, **kwargs):
        raise AttributeError("No constructor defined - class is abstract")
    __repr__ = _swig_repr
    __swig_destroy__ = _medfile.delete_SwigPyIterator_medfile

    def value(self):
        return _medfile.SwigPyIterator_medfile_value(self)

    def incr(self, n=1):
        return _medfile.SwigPyIterator_medfile_incr(self, n)

    def decr(self, n=1):
        return _medfile.SwigPyIterator_medfile_decr(self, n)

    def distance(self, x):
        return _medfile.SwigPyIterator_medfile_distance(self, x)

    def equal(self, x):
        return _medfile.SwigPyIterator_medfile_equal(self, x)

    def copy(self):
        return _medfile.SwigPyIterator_medfile_copy(self)

    def next(self):
        return _medfile.SwigPyIterator_medfile_next(self)

    def __next__(self):
        return _medfile.SwigPyIterator_medfile___next__(self)

    def previous(self):
        return _medfile.SwigPyIterator_medfile_previous(self)

    def advance(self, n):
        return _medfile.SwigPyIterator_medfile_advance(self, n)

    def __eq__(self, x):
        return _medfile.SwigPyIterator_medfile___eq__(self, x)

    def __ne__(self, x):
        return _medfile.SwigPyIterator_medfile___ne__(self, x)

    def __iadd__(self, n):
        return _medfile.SwigPyIterator_medfile___iadd__(self, n)

    def __isub__(self, n):
        return _medfile.SwigPyIterator_medfile___isub__(self, n)

    def __add__(self, n):
        return _medfile.SwigPyIterator_medfile___add__(self, n)

    def __sub__(self, *args):
        return _medfile.SwigPyIterator_medfile___sub__(self, *args)
    def __iter__(self): return self
    def __iter__(self):
        return self

# Register SwigPyIterator_medfile in _medfile:
_medfile.SwigPyIterator_medfile_swigregister(SwigPyIterator_medfile)
HAVE_CC_C99 = _medfile.HAVE_CC_C99
HAVE_CUSERID = _medfile.HAVE_CUSERID
HAVE_DLFCN_H = _medfile.HAVE_DLFCN_H
HAVE_FTIME = _medfile.HAVE_FTIME
HAVE_GETEUID = _medfile.HAVE_GETEUID
HAVE_GETPWUID = _medfile.HAVE_GETPWUID
HAVE_GETTIMEOFDAY = _medfile.HAVE_GETTIMEOFDAY
HAVE_H5PUBLIC_H = _medfile.HAVE_H5PUBLIC_H
HAVE_INT64 = _medfile.HAVE_INT64
HAVE_INTTYPES_H = _medfile.HAVE_INTTYPES_H
HAVE_MALLOC_H = _medfile.HAVE_MALLOC_H
HAVE_PWD_H = _medfile.HAVE_PWD_H
HAVE_STDBOOL_H = _medfile.HAVE_STDBOOL_H
HAVE_STDINT_H = _medfile.HAVE_STDINT_H
HAVE_STDIO_H = _medfile.HAVE_STDIO_H
HAVE_STDLIB_H = _medfile.HAVE_STDLIB_H
HAVE_STRINGS_H = _medfile.HAVE_STRINGS_H
HAVE_STRING_H = _medfile.HAVE_STRING_H
HAVE_SYS_STAT_H = _medfile.HAVE_SYS_STAT_H
HAVE_SYS_TIMEB_H = _medfile.HAVE_SYS_TIMEB_H
HAVE_SYS_TIME_H = _medfile.HAVE_SYS_TIME_H
HAVE_SYS_TYPES_H = _medfile.HAVE_SYS_TYPES_H
HAVE_UNISTD_H = _medfile.HAVE_UNISTD_H
HAVE__BOOL = _medfile.HAVE__BOOL
MED_CHECK_23FORMAT = _medfile.MED_CHECK_23FORMAT
MED_HAVE_FORTRAN = _medfile.MED_HAVE_FORTRAN
MESGERR = _medfile.MESGERR
PACKAGE = _medfile.PACKAGE
PACKAGE_BUGREPORT = _medfile.PACKAGE_BUGREPORT
PACKAGE_NAME = _medfile.PACKAGE_NAME
PACKAGE_STRING = _medfile.PACKAGE_STRING
PACKAGE_URL = _medfile.PACKAGE_URL
PACKAGE_VERSION = _medfile.PACKAGE_VERSION
SIZEOF_FORTRAN_INTEGER = _medfile.SIZEOF_FORTRAN_INTEGER
SIZEOF_INT = _medfile.SIZEOF_INT
SIZEOF_LONG = _medfile.SIZEOF_LONG
STDC_HEADERS = _medfile.STDC_HEADERS
VERSION = _medfile.VERSION
HDF_VERSION_REF = _medfile.HDF_VERSION_REF
HDF_VERSION_MAJOR_REF = _medfile.HDF_VERSION_MAJOR_REF
HDF_VERSION_MINOR_REF = _medfile.HDF_VERSION_MINOR_REF
HDF_VERSION_RELEASE_REF = _medfile.HDF_VERSION_RELEASE_REF
HDF_VERSION_NUM_REF = _medfile.HDF_VERSION_NUM_REF
H5F_LIBVER_18 = _medfile.H5F_LIBVER_18
MED_MAJOR_NUM = _medfile.MED_MAJOR_NUM
MED_MINOR_NUM = _medfile.MED_MINOR_NUM
MED_RELEASE_NUM = _medfile.MED_RELEASE_NUM
MED_3_LATEST_MINOR = _medfile.MED_3_LATEST_MINOR
MED_4_LATEST_MINOR = _medfile.MED_4_LATEST_MINOR
MED_40_LATEST_RELEASE = _medfile.MED_40_LATEST_RELEASE
MED_NUM_MAJEUR = _medfile.MED_NUM_MAJEUR
MED_NUM_MINEUR = _medfile.MED_NUM_MINEUR
MED_NUM_RELEASE = _medfile.MED_NUM_RELEASE
MED_VERSION_STR = _medfile.MED_VERSION_STR
MED_MAX_PARA = _medfile.MED_MAX_PARA
MED_COMMENT_SIZE = _medfile.MED_COMMENT_SIZE
MED_IDENT_SIZE = _medfile.MED_IDENT_SIZE
MED_NAME_SIZE = _medfile.MED_NAME_SIZE
MED_SNAME_SIZE = _medfile.MED_SNAME_SIZE
MED_LNAME_SIZE = _medfile.MED_LNAME_SIZE
MED_SNAME_BLANK = _medfile.MED_SNAME_BLANK
MED_NAME_BLANK = _medfile.MED_NAME_BLANK
MED_PATHNAME_SIZE = _medfile.MED_PATHNAME_SIZE
MED_MAX_CHFID_PATH = _medfile.MED_MAX_CHFID_PATH
MED_FULL_INTERLACE = _medfile.MED_FULL_INTERLACE
MED_NO_INTERLACE = _medfile.MED_NO_INTERLACE
MED_UNDEF_INTERLACE = _medfile.MED_UNDEF_INTERLACE
MED_UNDEF_STMODE = _medfile.MED_UNDEF_STMODE
MED_GLOBAL_STMODE = _medfile.MED_GLOBAL_STMODE
MED_COMPACT_STMODE = _medfile.MED_COMPACT_STMODE
MED_GLOBAL_PFLMODE = _medfile.MED_GLOBAL_PFLMODE
MED_COMPACT_PFLMODE = _medfile.MED_COMPACT_PFLMODE
MED_UNDEF_PFLMODE = _medfile.MED_UNDEF_PFLMODE
MED_ACC_RDONLY = _medfile.MED_ACC_RDONLY
MED_ACC_RDWR = _medfile.MED_ACC_RDWR
MED_ACC_RDEXT = _medfile.MED_ACC_RDEXT
MED_ACC_CREAT = _medfile.MED_ACC_CREAT
MED_ACC_UNDEF = _medfile.MED_ACC_UNDEF
MED_UNSTRUCTURED_MESH = _medfile.MED_UNSTRUCTURED_MESH
MED_STRUCTURED_MESH = _medfile.MED_STRUCTURED_MESH
MED_UNDEF_MESH_TYPE = _medfile.MED_UNDEF_MESH_TYPE
MED_CARTESIAN_GRID = _medfile.MED_CARTESIAN_GRID
MED_POLAR_GRID = _medfile.MED_POLAR_GRID
MED_CURVILINEAR_GRID = _medfile.MED_CURVILINEAR_GRID
MED_UNDEF_GRID_TYPE = _medfile.MED_UNDEF_GRID_TYPE
MED_CELL = _medfile.MED_CELL
MED_DESCENDING_FACE = _medfile.MED_DESCENDING_FACE
MED_DESCENDING_EDGE = _medfile.MED_DESCENDING_EDGE
MED_NODE = _medfile.MED_NODE
MED_NODE_ELEMENT = _medfile.MED_NODE_ELEMENT
MED_STRUCT_ELEMENT = _medfile.MED_STRUCT_ELEMENT
MED_ALL_ENTITY_TYPE = _medfile.MED_ALL_ENTITY_TYPE
MED_UNDEF_ENTITY_TYPE = _medfile.MED_UNDEF_ENTITY_TYPE
MED_N_ENTITY_TYPES = _medfile.MED_N_ENTITY_TYPES
MED_COORDINATE = _medfile.MED_COORDINATE
MED_CONNECTIVITY = _medfile.MED_CONNECTIVITY
MED_NAME = _medfile.MED_NAME
MED_NUMBER = _medfile.MED_NUMBER
MED_FAMILY_NUMBER = _medfile.MED_FAMILY_NUMBER
MED_COORDINATE_AXIS1 = _medfile.MED_COORDINATE_AXIS1
MED_COORDINATE_AXIS2 = _medfile.MED_COORDINATE_AXIS2
MED_COORDINATE_AXIS3 = _medfile.MED_COORDINATE_AXIS3
MED_INDEX_FACE = _medfile.MED_INDEX_FACE
MED_INDEX_NODE = _medfile.MED_INDEX_NODE
MED_GLOBAL_NUMBER = _medfile.MED_GLOBAL_NUMBER
MED_VARIABLE_ATTRIBUTE = _medfile.MED_VARIABLE_ATTRIBUTE
MED_COORDINATE_TRSF = _medfile.MED_COORDINATE_TRSF
MED_UNDEF_DATATYPE = _medfile.MED_UNDEF_DATATYPE
MED_INTERNAL_FLOAT32 = _medfile.MED_INTERNAL_FLOAT32
MED_INTERNAL_FLOAT64 = _medfile.MED_INTERNAL_FLOAT64
MED_INTERNAL_INT8 = _medfile.MED_INTERNAL_INT8
MED_INTERNAL_INT32 = _medfile.MED_INTERNAL_INT32
MED_INTERNAL_INT64 = _medfile.MED_INTERNAL_INT64
MED_INTERNAL_INT = _medfile.MED_INTERNAL_INT
MED_INTERNAL_NAME = _medfile.MED_INTERNAL_NAME
MED_INTERNAL_SNAME = _medfile.MED_INTERNAL_SNAME
MED_INTERNAL_LNAME = _medfile.MED_INTERNAL_LNAME
MED_INTERNAL_IDENT = _medfile.MED_INTERNAL_IDENT
MED_INTERNAL_CHAR = _medfile.MED_INTERNAL_CHAR
MED_INTERNAL_UNDEF = _medfile.MED_INTERNAL_UNDEF
MED_DOUBLE = _medfile.MED_DOUBLE
MED_FLOAT64 = _medfile.MED_FLOAT64
MED_FLOAT32 = _medfile.MED_FLOAT32
MED_INT32 = _medfile.MED_INT32
MED_INT64 = _medfile.MED_INT64
MED_INT = _medfile.MED_INT
MED_ATT_FLOAT64 = _medfile.MED_ATT_FLOAT64
MED_ATT_INT = _medfile.MED_ATT_INT
MED_ATT_NAME = _medfile.MED_ATT_NAME
MED_ATT_UNDEF = _medfile.MED_ATT_UNDEF
MED_MESH = _medfile.MED_MESH
MED_FIELD = _medfile.MED_FIELD
MED_LIBRARY = _medfile.MED_LIBRARY
MED_FILE = _medfile.MED_FILE
MED_MESH_SUPPORT = _medfile.MED_MESH_SUPPORT
MED_ELSTRUCT = _medfile.MED_ELSTRUCT
MED_FAMILY = _medfile.MED_FAMILY
MED_EQUIVALENCE = _medfile.MED_EQUIVALENCE
MED_GROUP = _medfile.MED_GROUP
MED_JOINT = _medfile.MED_JOINT
MED_LOCALIZATION = _medfile.MED_LOCALIZATION
MED_PROFILE = _medfile.MED_PROFILE
MED_FILTER = _medfile.MED_FILTER
MED_INTERPOLATION = _medfile.MED_INTERPOLATION
MED_NUMERICAL_DATA = _medfile.MED_NUMERICAL_DATA
MED_LINK = _medfile.MED_LINK
MED_CLASS_UNDEF = _medfile.MED_CLASS_UNDEF
MED_CLASS_ALL = _medfile.MED_CLASS_ALL
MED_POINT1 = _medfile.MED_POINT1
MED_SEG2 = _medfile.MED_SEG2
MED_SEG3 = _medfile.MED_SEG3
MED_SEG4 = _medfile.MED_SEG4
MED_TRIA3 = _medfile.MED_TRIA3
MED_QUAD4 = _medfile.MED_QUAD4
MED_TRIA6 = _medfile.MED_TRIA6
MED_TRIA7 = _medfile.MED_TRIA7
MED_QUAD8 = _medfile.MED_QUAD8
MED_QUAD9 = _medfile.MED_QUAD9
MED_TETRA4 = _medfile.MED_TETRA4
MED_PYRA5 = _medfile.MED_PYRA5
MED_PENTA6 = _medfile.MED_PENTA6
MED_HEXA8 = _medfile.MED_HEXA8
MED_TETRA10 = _medfile.MED_TETRA10
MED_OCTA12 = _medfile.MED_OCTA12
MED_PYRA13 = _medfile.MED_PYRA13
MED_PENTA15 = _medfile.MED_PENTA15
MED_PENTA18 = _medfile.MED_PENTA18
MED_HEXA20 = _medfile.MED_HEXA20
MED_HEXA27 = _medfile.MED_HEXA27
MED_POLYGON = _medfile.MED_POLYGON
MED_POLYGON2 = _medfile.MED_POLYGON2
MED_POLYHEDRON = _medfile.MED_POLYHEDRON
MED_STRUCT_GEO_INTERNAL = _medfile.MED_STRUCT_GEO_INTERNAL
MED_STRUCT_GEO_SUP_INTERNAL = _medfile.MED_STRUCT_GEO_SUP_INTERNAL
MED_NONE = _medfile.MED_NONE
MED_NO_GEOTYPE = _medfile.MED_NO_GEOTYPE
MED_UNDEF_GEOTYPE = _medfile.MED_UNDEF_GEOTYPE
MED_UNDEF_GEOMETRY_TYPE = _medfile.MED_UNDEF_GEOMETRY_TYPE
MED_ALL_GEOTYPE = _medfile.MED_ALL_GEOTYPE
MED_GEO_ALL = _medfile.MED_GEO_ALL
MED_N_CELL_GEO = _medfile.MED_N_CELL_GEO
MED_N_CELL_FIXED_GEO = _medfile.MED_N_CELL_FIXED_GEO
MED_N_CELL_GEO_FIXED_CON = _medfile.MED_N_CELL_GEO_FIXED_CON
MED_N_FACE_GEO = _medfile.MED_N_FACE_GEO
MED_N_FACE_FIXED_GEO = _medfile.MED_N_FACE_FIXED_GEO
MED_N_FACE_GEO_FIXED_CON = _medfile.MED_N_FACE_GEO_FIXED_CON
MED_N_EDGE_TYPES = _medfile.MED_N_EDGE_TYPES
MED_N_EDGE_FIXED_GEO = _medfile.MED_N_EDGE_FIXED_GEO
MED_N_EDGE_GEO_FIXED_CON = _medfile.MED_N_EDGE_GEO_FIXED_CON
MED_N_NODE_GEO = _medfile.MED_N_NODE_GEO
MED_N_NODE_FIXED_GEO = _medfile.MED_N_NODE_FIXED_GEO
MED_N_NODE_GEO_FIXED_CON = _medfile.MED_N_NODE_GEO_FIXED_CON
MED_NODAL = _medfile.MED_NODAL
MED_DESCENDING = _medfile.MED_DESCENDING
MED_UNDEF_CONNECTIVITY_MODE = _medfile.MED_UNDEF_CONNECTIVITY_MODE
MED_NO_CMODE = _medfile.MED_NO_CMODE
MED_CARTESIAN = _medfile.MED_CARTESIAN
MED_CYLINDRICAL = _medfile.MED_CYLINDRICAL
MED_SPHERICAL = _medfile.MED_SPHERICAL
MED_UNDEF_AXIS_TYPE = _medfile.MED_UNDEF_AXIS_TYPE
MED_FALSE = _medfile.MED_FALSE
MED_TRUE = _medfile.MED_TRUE
MED_GAUSS_ELNO = _medfile.MED_GAUSS_ELNO
MED_IPOINT_ELNO = _medfile.MED_IPOINT_ELNO
MED_NO_NAME = _medfile.MED_NO_NAME
MED_NO_MESHNAME = _medfile.MED_NO_MESHNAME
MED_NO_MESH = _medfile.MED_NO_MESH
MED_NO_MESH_SUPPORT = _medfile.MED_NO_MESH_SUPPORT
MED_NO_LOCALIZATION = _medfile.MED_NO_LOCALIZATION
MED_NO_INTERPOLATION = _medfile.MED_NO_INTERPOLATION
MED_NO_IPOINT_INTERNAL = _medfile.MED_NO_IPOINT_INTERNAL
MED_NO_PROFILE = _medfile.MED_NO_PROFILE
MED_NO_GROUP = _medfile.MED_NO_GROUP
MED_ALLENTITIES_PROFILE = _medfile.MED_ALLENTITIES_PROFILE
MED_NO_PROFILE_INTERNAL = _medfile.MED_NO_PROFILE_INTERNAL
MED_SAME_PROFILE_INTERNAL = _medfile.MED_SAME_PROFILE_INTERNAL
MED_ALL_CONSTITUENT = _medfile.MED_ALL_CONSTITUENT
MED_UNDEF_SIZE = _medfile.MED_UNDEF_SIZE
MED_NO_PROFILE_SIZE = _medfile.MED_NO_PROFILE_SIZE
MED_SORT_DTIT = _medfile.MED_SORT_DTIT
MED_SORT_ITDT = _medfile.MED_SORT_ITDT
MED_SORT_UNDEF = _medfile.MED_SORT_UNDEF
MED_ALL_DT = _medfile.MED_ALL_DT
MED_ALL_IT = _medfile.MED_ALL_IT
MED_NO_DT = _medfile.MED_NO_DT
MED_NO_IT = _medfile.MED_NO_IT
MED_UNDEF_DT = _medfile.MED_UNDEF_DT
MED_ATT_NOT_FILLED = _medfile.MED_ATT_NOT_FILLED
MED_MAX_FILTER_SPACES = _medfile.MED_MAX_FILTER_SPACES
class med_filter(object):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr
    nspaces = property(_medfile.med_filter_nspaces_get, _medfile.med_filter_nspaces_set)
    memspace = property(_medfile.med_filter_memspace_get, _medfile.med_filter_memspace_set)
    diskspace = property(_medfile.med_filter_diskspace_get, _medfile.med_filter_diskspace_set)
    nentity = property(_medfile.med_filter_nentity_get, _medfile.med_filter_nentity_set)
    nvaluesperentity = property(_medfile.med_filter_nvaluesperentity_get, _medfile.med_filter_nvaluesperentity_set)
    nconstituentpervalue = property(_medfile.med_filter_nconstituentpervalue_get, _medfile.med_filter_nconstituentpervalue_set)
    constituentselect = property(_medfile.med_filter_constituentselect_get, _medfile.med_filter_constituentselect_set)
    switchmode = property(_medfile.med_filter_switchmode_get, _medfile.med_filter_switchmode_set)
    filterarraysize = property(_medfile.med_filter_filterarraysize_get, _medfile.med_filter_filterarraysize_set)
    filterarray23v30 = property(_medfile.med_filter_filterarray23v30_get, _medfile.med_filter_filterarray23v30_set)
    profilearraysize = property(_medfile.med_filter_profilearraysize_get, _medfile.med_filter_profilearraysize_set)
    storagemode = property(_medfile.med_filter_storagemode_get, _medfile.med_filter_storagemode_set)
    profilename = property(_medfile.med_filter_profilename_get, _medfile.med_filter_profilename_set)

    def __init__(self):
        r"""__init__(self) -> med_filter"""
        _medfile.med_filter_swiginit(self, _medfile.new_med_filter())
    __swig_destroy__ = _medfile.delete_med_filter

# Register med_filter in _medfile:
_medfile.med_filter_swigregister(med_filter)
MED_NO_FILTER_SIZE = _medfile.MED_NO_FILTER_SIZE
MED_NO_PROFILE_F = _medfile.MED_NO_PROFILE_F
class med_file_version(object):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr
    majeur = property(_medfile.med_file_version_majeur_get, _medfile.med_file_version_majeur_set)
    mineur = property(_medfile.med_file_version_mineur_get, _medfile.med_file_version_mineur_set)
    release = property(_medfile.med_file_version_release_get, _medfile.med_file_version_release_set)

    def __init__(self):
        r"""__init__(self) -> med_file_version"""
        _medfile.med_file_version_swiginit(self, _medfile.new_med_file_version())
    __swig_destroy__ = _medfile.delete_med_file_version

# Register med_file_version in _medfile:
_medfile.med_file_version_swigregister(med_file_version)
class med_memfile(object):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr
    app_image_ptr = property(_medfile.med_memfile_app_image_ptr_get, _medfile.med_memfile_app_image_ptr_set)
    app_image_size = property(_medfile.med_memfile_app_image_size_get, _medfile.med_memfile_app_image_size_set)
    ref_count = property(_medfile.med_memfile_ref_count_get, _medfile.med_memfile_ref_count_set)
    fapl_image_ptr = property(_medfile.med_memfile_fapl_image_ptr_get, _medfile.med_memfile_fapl_image_ptr_set)
    fapl_image_size = property(_medfile.med_memfile_fapl_image_size_get, _medfile.med_memfile_fapl_image_size_set)
    fapl_ref_count = property(_medfile.med_memfile_fapl_ref_count_get, _medfile.med_memfile_fapl_ref_count_set)
    vfd_image_ptr = property(_medfile.med_memfile_vfd_image_ptr_get, _medfile.med_memfile_vfd_image_ptr_set)
    vfd_image_size = property(_medfile.med_memfile_vfd_image_size_get, _medfile.med_memfile_vfd_image_size_set)
    vfd_ref_count = property(_medfile.med_memfile_vfd_ref_count_get, _medfile.med_memfile_vfd_ref_count_set)
    flags = property(_medfile.med_memfile_flags_get, _medfile.med_memfile_flags_set)

    def __init__(self):
        r"""__init__(self) -> med_memfile"""
        _medfile.med_memfile_swiginit(self, _medfile.new_med_memfile())
    __swig_destroy__ = _medfile.delete_med_memfile

# Register med_memfile in _medfile:
_medfile.med_memfile_swigregister(med_memfile)

def MEDgetEntityTypeIt(entitytype):
    return _medfile.MEDgetEntityTypeIt(entitytype)

def MEDgetCellGeometryTypeIt(geotype):
    return _medfile.MEDgetCellGeometryTypeIt(geotype)

def MEDgetFaceGeometryTypeIt(geotype):
    return _medfile.MEDgetFaceGeometryTypeIt(geotype)

def MEDgetEdgeGeometryTypeIt(geotype):
    return _medfile.MEDgetEdgeGeometryTypeIt(geotype)

def MEDgetNodeGeometryTypeIt(geotype):
    return _medfile.MEDgetNodeGeometryTypeIt(geotype)

def MEDgetEntityGeometryTypeIt(entitytype, geotype):
    return _medfile.MEDgetEntityGeometryTypeIt(entitytype, geotype)

def MEDgetGeometryTypeName(geotype):
    return _medfile.MEDgetGeometryTypeName(geotype)

def MEDgetEntityTypeName(entitytype):
    return _medfile.MEDgetEntityTypeName(entitytype)
MED_PARTICLE_NAME = _medfile.MED_PARTICLE_NAME
MED_BALL_NAME = _medfile.MED_BALL_NAME
MED_BEAM_NAME = _medfile.MED_BEAM_NAME
MED_PARTICLE_LABEL = _medfile.MED_PARTICLE_LABEL
MED_BALL_DIAMETER = _medfile.MED_BALL_DIAMETER
MED_BEAM_THICKNESS = _medfile.MED_BEAM_THICKNESS
import med.medenum
class MEDBOOL(object):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    def iterator(self):
        return _medfile.MEDBOOL_iterator(self)
    def __iter__(self):
        return self.iterator()

    def __nonzero__(self):
        return _medfile.MEDBOOL___nonzero__(self)

    def __bool__(self):
        return _medfile.MEDBOOL___bool__(self)

    def __len__(self):
        return _medfile.MEDBOOL___len__(self)

    def __getslice__(self, i, j):
        return _medfile.MEDBOOL___getslice__(self, i, j)

    def __setslice__(self, *args):
        return _medfile.MEDBOOL___setslice__(self, *args)

    def __delslice__(self, i, j):
        return _medfile.MEDBOOL___delslice__(self, i, j)

    def __delitem__(self, *args):
        return _medfile.MEDBOOL___delitem__(self, *args)

    def __getitem__(self, *args):
        return _medfile.MEDBOOL___getitem__(self, *args)

    def __setitem__(self, *args):
        return _medfile.MEDBOOL___setitem__(self, *args)

    def pop(self):
        return _medfile.MEDBOOL_pop(self)

    def append(self, x):
        return _medfile.MEDBOOL_append(self, x)

    def empty(self):
        return _medfile.MEDBOOL_empty(self)

    def size(self):
        return _medfile.MEDBOOL_size(self)

    def swap(self, v):
        return _medfile.MEDBOOL_swap(self, v)

    def begin(self):
        return _medfile.MEDBOOL_begin(self)

    def end(self):
        return _medfile.MEDBOOL_end(self)

    def rbegin(self):
        return _medfile.MEDBOOL_rbegin(self)

    def rend(self):
        return _medfile.MEDBOOL_rend(self)

    def clear(self):
        return _medfile.MEDBOOL_clear(self)

    def get_allocator(self):
        return _medfile.MEDBOOL_get_allocator(self)

    def pop_back(self):
        return _medfile.MEDBOOL_pop_back(self)

    def erase(self, *args):
        return _medfile.MEDBOOL_erase(self, *args)

    def __init__(self, *args):
        _medfile.MEDBOOL_swiginit(self, _medfile.new_MEDBOOL(*args))

    def push_back(self, x):
        return _medfile.MEDBOOL_push_back(self, x)

    def front(self):
        return _medfile.MEDBOOL_front(self)

    def back(self):
        return _medfile.MEDBOOL_back(self)

    def assign(self, n, x):
        return _medfile.MEDBOOL_assign(self, n, x)

    def resize(self, *args):
        return _medfile.MEDBOOL_resize(self, *args)

    def insert(self, *args):
        return _medfile.MEDBOOL_insert(self, *args)

    def reserve(self, n):
        return _medfile.MEDBOOL_reserve(self, n)

    def capacity(self):
        return _medfile.MEDBOOL_capacity(self)
    __swig_destroy__ = _medfile.delete_MEDBOOL

# Register MEDBOOL in _medfile:
_medfile.MEDBOOL_swigregister(MEDBOOL)
cvar = _medfile.cvar
MED_GET_ENTITY_TYPENAME = cvar.MED_GET_ENTITY_TYPENAME
MED_GET_CELL_GEOMETRY_TYPENAME = cvar.MED_GET_CELL_GEOMETRY_TYPENAME
MED_GET_FACE_GEOMETRY_TYPENAME = cvar.MED_GET_FACE_GEOMETRY_TYPENAME
MED_GET_CELL_GEOMETRY_TYPE_FROM_ENTITY_TYPE = cvar.MED_GET_CELL_GEOMETRY_TYPE_FROM_ENTITY_TYPE
MED_GET_N_FIXED_GEO_FOR_ENTITY_TYPE_IT = cvar.MED_GET_N_FIXED_GEO_FOR_ENTITY_TYPE_IT


MEDBOOL.__str__= lambda self: str([x for x in self])
MEDBOOL.__repr__= lambda self: "MEDBOOL("+str([x for x in self])+")"

class MEDFLOAT(object):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    def iterator(self):
        return _medfile.MEDFLOAT_iterator(self)
    def __iter__(self):
        return self.iterator()

    def __nonzero__(self):
        return _medfile.MEDFLOAT___nonzero__(self)

    def __bool__(self):
        return _medfile.MEDFLOAT___bool__(self)

    def __len__(self):
        return _medfile.MEDFLOAT___len__(self)

    def __getslice__(self, i, j):
        return _medfile.MEDFLOAT___getslice__(self, i, j)

    def __setslice__(self, *args):
        return _medfile.MEDFLOAT___setslice__(self, *args)

    def __delslice__(self, i, j):
        return _medfile.MEDFLOAT___delslice__(self, i, j)

    def __delitem__(self, *args):
        return _medfile.MEDFLOAT___delitem__(self, *args)

    def __getitem__(self, *args):
        return _medfile.MEDFLOAT___getitem__(self, *args)

    def __setitem__(self, *args):
        return _medfile.MEDFLOAT___setitem__(self, *args)

    def pop(self):
        return _medfile.MEDFLOAT_pop(self)

    def append(self, x):
        return _medfile.MEDFLOAT_append(self, x)

    def empty(self):
        return _medfile.MEDFLOAT_empty(self)

    def size(self):
        return _medfile.MEDFLOAT_size(self)

    def swap(self, v):
        return _medfile.MEDFLOAT_swap(self, v)

    def begin(self):
        return _medfile.MEDFLOAT_begin(self)

    def end(self):
        return _medfile.MEDFLOAT_end(self)

    def rbegin(self):
        return _medfile.MEDFLOAT_rbegin(self)

    def rend(self):
        return _medfile.MEDFLOAT_rend(self)

    def clear(self):
        return _medfile.MEDFLOAT_clear(self)

    def get_allocator(self):
        return _medfile.MEDFLOAT_get_allocator(self)

    def pop_back(self):
        return _medfile.MEDFLOAT_pop_back(self)

    def erase(self, *args):
        return _medfile.MEDFLOAT_erase(self, *args)

    def __init__(self, *args):
        _medfile.MEDFLOAT_swiginit(self, _medfile.new_MEDFLOAT(*args))

    def push_back(self, x):
        return _medfile.MEDFLOAT_push_back(self, x)

    def front(self):
        return _medfile.MEDFLOAT_front(self)

    def back(self):
        return _medfile.MEDFLOAT_back(self)

    def assign(self, n, x):
        return _medfile.MEDFLOAT_assign(self, n, x)

    def resize(self, *args):
        return _medfile.MEDFLOAT_resize(self, *args)

    def insert(self, *args):
        return _medfile.MEDFLOAT_insert(self, *args)

    def reserve(self, n):
        return _medfile.MEDFLOAT_reserve(self, n)

    def capacity(self):
        return _medfile.MEDFLOAT_capacity(self)

    def __iadd__(self, value):
        return _medfile.MEDFLOAT___iadd__(self, value)

    def __add__(self, value):
        return _medfile.MEDFLOAT___add__(self, value)

    def __isub__(self, value):
        return _medfile.MEDFLOAT___isub__(self, value)

    def __sub__(self, value):
        return _medfile.MEDFLOAT___sub__(self, value)

    def __imul__(self, value):
        return _medfile.MEDFLOAT___imul__(self, value)

    def __mul__(self, value):
        return _medfile.MEDFLOAT___mul__(self, value)

    def __itruediv__(self, *args):
        return _medfile.MEDFLOAT___itruediv__(self, *args)
    __idiv__ = __itruediv__



    def __truediv__(self, *args):
        return _medfile.MEDFLOAT___truediv__(self, *args)
    __div__ = __truediv__



    def __le__(self, value):
        return _medfile.MEDFLOAT___le__(self, value)

    def __lt__(self, value):
        return _medfile.MEDFLOAT___lt__(self, value)

    def __gt__(self, value):
        return _medfile.MEDFLOAT___gt__(self, value)

    def __ge__(self, value):
        return _medfile.MEDFLOAT___ge__(self, value)

    def __eq__(self, value):
        return _medfile.MEDFLOAT___eq__(self, value)

    def __ne__(self, value):
        return _medfile.MEDFLOAT___ne__(self, value)
    __swig_destroy__ = _medfile.delete_MEDFLOAT

# Register MEDFLOAT in _medfile:
_medfile.MEDFLOAT_swigregister(MEDFLOAT)

MEDFLOAT.__str__= lambda self: str([x for x in self])
MEDFLOAT.__repr__= lambda self:"MEDFLOAT" +"("+str([x for x in self])+")"


MEDFLOAT64=MEDFLOAT
MEDDOUBLE=MEDFLOAT

class MEDFLOAT32(object):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    def iterator(self):
        return _medfile.MEDFLOAT32_iterator(self)
    def __iter__(self):
        return self.iterator()

    def __nonzero__(self):
        return _medfile.MEDFLOAT32___nonzero__(self)

    def __bool__(self):
        return _medfile.MEDFLOAT32___bool__(self)

    def __len__(self):
        return _medfile.MEDFLOAT32___len__(self)

    def __getslice__(self, i, j):
        return _medfile.MEDFLOAT32___getslice__(self, i, j)

    def __setslice__(self, *args):
        return _medfile.MEDFLOAT32___setslice__(self, *args)

    def __delslice__(self, i, j):
        return _medfile.MEDFLOAT32___delslice__(self, i, j)

    def __delitem__(self, *args):
        return _medfile.MEDFLOAT32___delitem__(self, *args)

    def __getitem__(self, *args):
        return _medfile.MEDFLOAT32___getitem__(self, *args)

    def __setitem__(self, *args):
        return _medfile.MEDFLOAT32___setitem__(self, *args)

    def pop(self):
        return _medfile.MEDFLOAT32_pop(self)

    def append(self, x):
        return _medfile.MEDFLOAT32_append(self, x)

    def empty(self):
        return _medfile.MEDFLOAT32_empty(self)

    def size(self):
        return _medfile.MEDFLOAT32_size(self)

    def swap(self, v):
        return _medfile.MEDFLOAT32_swap(self, v)

    def begin(self):
        return _medfile.MEDFLOAT32_begin(self)

    def end(self):
        return _medfile.MEDFLOAT32_end(self)

    def rbegin(self):
        return _medfile.MEDFLOAT32_rbegin(self)

    def rend(self):
        return _medfile.MEDFLOAT32_rend(self)

    def clear(self):
        return _medfile.MEDFLOAT32_clear(self)

    def get_allocator(self):
        return _medfile.MEDFLOAT32_get_allocator(self)

    def pop_back(self):
        return _medfile.MEDFLOAT32_pop_back(self)

    def erase(self, *args):
        return _medfile.MEDFLOAT32_erase(self, *args)

    def __init__(self, *args):
        _medfile.MEDFLOAT32_swiginit(self, _medfile.new_MEDFLOAT32(*args))

    def push_back(self, x):
        return _medfile.MEDFLOAT32_push_back(self, x)

    def front(self):
        return _medfile.MEDFLOAT32_front(self)

    def back(self):
        return _medfile.MEDFLOAT32_back(self)

    def assign(self, n, x):
        return _medfile.MEDFLOAT32_assign(self, n, x)

    def resize(self, *args):
        return _medfile.MEDFLOAT32_resize(self, *args)

    def insert(self, *args):
        return _medfile.MEDFLOAT32_insert(self, *args)

    def reserve(self, n):
        return _medfile.MEDFLOAT32_reserve(self, n)

    def capacity(self):
        return _medfile.MEDFLOAT32_capacity(self)

    def __iadd__(self, value):
        return _medfile.MEDFLOAT32___iadd__(self, value)

    def __add__(self, value):
        return _medfile.MEDFLOAT32___add__(self, value)

    def __isub__(self, value):
        return _medfile.MEDFLOAT32___isub__(self, value)

    def __sub__(self, value):
        return _medfile.MEDFLOAT32___sub__(self, value)

    def __imul__(self, value):
        return _medfile.MEDFLOAT32___imul__(self, value)

    def __mul__(self, value):
        return _medfile.MEDFLOAT32___mul__(self, value)

    def __itruediv__(self, *args):
        return _medfile.MEDFLOAT32___itruediv__(self, *args)
    __idiv__ = __itruediv__



    def __truediv__(self, *args):
        return _medfile.MEDFLOAT32___truediv__(self, *args)
    __div__ = __truediv__



    def __le__(self, value):
        return _medfile.MEDFLOAT32___le__(self, value)

    def __lt__(self, value):
        return _medfile.MEDFLOAT32___lt__(self, value)

    def __gt__(self, value):
        return _medfile.MEDFLOAT32___gt__(self, value)

    def __ge__(self, value):
        return _medfile.MEDFLOAT32___ge__(self, value)

    def __eq__(self, value):
        return _medfile.MEDFLOAT32___eq__(self, value)

    def __ne__(self, value):
        return _medfile.MEDFLOAT32___ne__(self, value)
    __swig_destroy__ = _medfile.delete_MEDFLOAT32

# Register MEDFLOAT32 in _medfile:
_medfile.MEDFLOAT32_swigregister(MEDFLOAT32)

MEDFLOAT32.__str__= lambda self: str([x for x in self])
MEDFLOAT32.__repr__= lambda self:"MEDFLOAT32" +"("+str([x for x in self])+")"

class MEDINT(object):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    def iterator(self):
        return _medfile.MEDINT_iterator(self)
    def __iter__(self):
        return self.iterator()

    def __nonzero__(self):
        return _medfile.MEDINT___nonzero__(self)

    def __bool__(self):
        return _medfile.MEDINT___bool__(self)

    def __len__(self):
        return _medfile.MEDINT___len__(self)

    def __getslice__(self, i, j):
        return _medfile.MEDINT___getslice__(self, i, j)

    def __setslice__(self, *args):
        return _medfile.MEDINT___setslice__(self, *args)

    def __delslice__(self, i, j):
        return _medfile.MEDINT___delslice__(self, i, j)

    def __delitem__(self, *args):
        return _medfile.MEDINT___delitem__(self, *args)

    def __getitem__(self, *args):
        return _medfile.MEDINT___getitem__(self, *args)

    def __setitem__(self, *args):
        return _medfile.MEDINT___setitem__(self, *args)

    def pop(self):
        return _medfile.MEDINT_pop(self)

    def append(self, x):
        return _medfile.MEDINT_append(self, x)

    def empty(self):
        return _medfile.MEDINT_empty(self)

    def size(self):
        return _medfile.MEDINT_size(self)

    def swap(self, v):
        return _medfile.MEDINT_swap(self, v)

    def begin(self):
        return _medfile.MEDINT_begin(self)

    def end(self):
        return _medfile.MEDINT_end(self)

    def rbegin(self):
        return _medfile.MEDINT_rbegin(self)

    def rend(self):
        return _medfile.MEDINT_rend(self)

    def clear(self):
        return _medfile.MEDINT_clear(self)

    def get_allocator(self):
        return _medfile.MEDINT_get_allocator(self)

    def pop_back(self):
        return _medfile.MEDINT_pop_back(self)

    def erase(self, *args):
        return _medfile.MEDINT_erase(self, *args)

    def __init__(self, *args):
        _medfile.MEDINT_swiginit(self, _medfile.new_MEDINT(*args))

    def push_back(self, x):
        return _medfile.MEDINT_push_back(self, x)

    def front(self):
        return _medfile.MEDINT_front(self)

    def back(self):
        return _medfile.MEDINT_back(self)

    def assign(self, n, x):
        return _medfile.MEDINT_assign(self, n, x)

    def resize(self, *args):
        return _medfile.MEDINT_resize(self, *args)

    def insert(self, *args):
        return _medfile.MEDINT_insert(self, *args)

    def reserve(self, n):
        return _medfile.MEDINT_reserve(self, n)

    def capacity(self):
        return _medfile.MEDINT_capacity(self)

    def __iadd__(self, value):
        return _medfile.MEDINT___iadd__(self, value)

    def __add__(self, value):
        return _medfile.MEDINT___add__(self, value)

    def __isub__(self, value):
        return _medfile.MEDINT___isub__(self, value)

    def __sub__(self, value):
        return _medfile.MEDINT___sub__(self, value)

    def __imul__(self, value):
        return _medfile.MEDINT___imul__(self, value)

    def __mul__(self, value):
        return _medfile.MEDINT___mul__(self, value)

    def __itruediv__(self, *args):
        return _medfile.MEDINT___itruediv__(self, *args)
    __idiv__ = __itruediv__



    def __truediv__(self, *args):
        return _medfile.MEDINT___truediv__(self, *args)
    __div__ = __truediv__



    def __le__(self, value):
        return _medfile.MEDINT___le__(self, value)

    def __lt__(self, value):
        return _medfile.MEDINT___lt__(self, value)

    def __gt__(self, value):
        return _medfile.MEDINT___gt__(self, value)

    def __ge__(self, value):
        return _medfile.MEDINT___ge__(self, value)

    def __eq__(self, value):
        return _medfile.MEDINT___eq__(self, value)

    def __ne__(self, value):
        return _medfile.MEDINT___ne__(self, value)
    __swig_destroy__ = _medfile.delete_MEDINT

# Register MEDINT in _medfile:
_medfile.MEDINT_swigregister(MEDINT)

MEDINT.__str__= lambda self: str([x for x in self])
MEDINT.__repr__= lambda self:"MEDINT" +"("+str([x for x in self])+")"


MEDINT32=MEDINT


MEDINT64=None

class MEDCHAR(object):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    def iterator(self):
        return _medfile.MEDCHAR_iterator(self)
    def __iter__(self):
        return self.iterator()

    def __nonzero__(self):
        return _medfile.MEDCHAR___nonzero__(self)

    def __bool__(self):
        return _medfile.MEDCHAR___bool__(self)

    def __len__(self):
        return _medfile.MEDCHAR___len__(self)

    def __getslice__(self, i, j):
        return _medfile.MEDCHAR___getslice__(self, i, j)

    def __setslice__(self, *args):
        return _medfile.MEDCHAR___setslice__(self, *args)

    def __delslice__(self, i, j):
        return _medfile.MEDCHAR___delslice__(self, i, j)

    def __delitem__(self, *args):
        return _medfile.MEDCHAR___delitem__(self, *args)

    def __getitem__(self, *args):
        return _medfile.MEDCHAR___getitem__(self, *args)

    def __setitem__(self, *args):
        return _medfile.MEDCHAR___setitem__(self, *args)

    def pop(self):
        return _medfile.MEDCHAR_pop(self)

    def append(self, x):
        return _medfile.MEDCHAR_append(self, x)

    def empty(self):
        return _medfile.MEDCHAR_empty(self)

    def size(self):
        return _medfile.MEDCHAR_size(self)

    def swap(self, v):
        return _medfile.MEDCHAR_swap(self, v)

    def begin(self):
        return _medfile.MEDCHAR_begin(self)

    def end(self):
        return _medfile.MEDCHAR_end(self)

    def rbegin(self):
        return _medfile.MEDCHAR_rbegin(self)

    def rend(self):
        return _medfile.MEDCHAR_rend(self)

    def clear(self):
        return _medfile.MEDCHAR_clear(self)

    def get_allocator(self):
        return _medfile.MEDCHAR_get_allocator(self)

    def pop_back(self):
        return _medfile.MEDCHAR_pop_back(self)

    def erase(self, *args):
        return _medfile.MEDCHAR_erase(self, *args)

    def __init__(self, *args):
        _medfile.MEDCHAR_swiginit(self, _medfile.new_MEDCHAR(*args))

    def push_back(self, x):
        return _medfile.MEDCHAR_push_back(self, x)

    def front(self):
        return _medfile.MEDCHAR_front(self)

    def back(self):
        return _medfile.MEDCHAR_back(self)

    def assign(self, n, x):
        return _medfile.MEDCHAR_assign(self, n, x)

    def resize(self, *args):
        return _medfile.MEDCHAR_resize(self, *args)

    def insert(self, *args):
        return _medfile.MEDCHAR_insert(self, *args)

    def reserve(self, n):
        return _medfile.MEDCHAR_reserve(self, n)

    def capacity(self):
        return _medfile.MEDCHAR_capacity(self)

    def __iadd__(self, value):
        return _medfile.MEDCHAR___iadd__(self, value)

    def __add__(self, value):
        return _medfile.MEDCHAR___add__(self, value)

    def __isub__(self, value):
        return _medfile.MEDCHAR___isub__(self, value)

    def __sub__(self, value):
        return _medfile.MEDCHAR___sub__(self, value)

    def __imul__(self, value):
        return _medfile.MEDCHAR___imul__(self, value)

    def __mul__(self, value):
        return _medfile.MEDCHAR___mul__(self, value)

    def __itruediv__(self, *args):
        return _medfile.MEDCHAR___itruediv__(self, *args)
    __idiv__ = __itruediv__



    def __truediv__(self, *args):
        return _medfile.MEDCHAR___truediv__(self, *args)
    __div__ = __truediv__



    def __le__(self, value):
        return _medfile.MEDCHAR___le__(self, value)

    def __lt__(self, value):
        return _medfile.MEDCHAR___lt__(self, value)

    def __gt__(self, value):
        return _medfile.MEDCHAR___gt__(self, value)

    def __ge__(self, value):
        return _medfile.MEDCHAR___ge__(self, value)

    def __eq__(self, value):
        return _medfile.MEDCHAR___eq__(self, value)

    def __ne__(self, value):
        return _medfile.MEDCHAR___ne__(self, value)
    __swig_destroy__ = _medfile.delete_MEDCHAR

# Register MEDCHAR in _medfile:
_medfile.MEDCHAR_swigregister(MEDCHAR)

MEDCHAR.__str__= lambda self: str([x for x in self])
MEDCHAR.__repr__= lambda self:"MEDCHAR" +"("+str([x for x in self])+")"


MEDCHAR.__str__= lambda self: str([x for x in self])
MEDCHAR.__repr__= lambda self:"MEDCHAR" +"("+str([x for x in self])+")"


MEDCHAR.__str__= lambda self: str([x for x in self])
MEDCHAR.__repr__= lambda self:"MEDCHAR" +"("+str([x for x in self])+")"


def MEDfileOpen(filename, accessmode):
    r"""
    MEDfileOpen(filename, accessmode) -> med_idt

    Parameters
    ----------
    filename: char const *const
    accessmode: enum med_access_mode const

    """
    return _medfile.MEDfileOpen(filename, accessmode)

def MEDfileVersionOpen(filename, accessmode, major, minor, release):
    r"""
    MEDfileVersionOpen(filename, accessmode, major, minor, release) -> med_idt

    Parameters
    ----------
    filename: char const *const
    accessmode: enum med_access_mode const
    major: med_int const
    minor: med_int const
    release: med_int const

    """
    return _medfile.MEDfileVersionOpen(filename, accessmode, major, minor, release)

def MEDfileExist(filename, accessmode):
    r"""
    MEDfileExist(filename, accessmode) -> med_err

    Parameters
    ----------
    filename: char const *const
    accessmode: enum med_access_mode const

    """
    return _medfile.MEDfileExist(filename, accessmode)

def MEDparFileOpen(filename, accessmode, comm, info):
    r"""
    MEDparFileOpen(filename, accessmode, comm, info) -> med_idt

    Parameters
    ----------
    filename: char const *const
    accessmode: enum med_access_mode const
    comm: MPI_Comm const
    info: MPI_Info const

    """
    return _medfile.MEDparFileOpen(filename, accessmode, comm, info)

def MEDfileName(fid):
    r"""MEDfileName(fid) -> str"""
    return _medfile.MEDfileName(fid)

def MEDfileClose(fid):
    r"""
    MEDfileClose(fid) -> med_err

    Parameters
    ----------
    fid: med_idt

    """
    return _medfile.MEDfileClose(fid)

def MEDfileCommentWr(fid, comment):
    r"""
    MEDfileCommentWr(fid, comment) -> med_err

    Parameters
    ----------
    fid: med_idt const
    comment: char const *const

    """
    return _medfile.MEDfileCommentWr(fid, comment)

def MEDfileCommentRd(fid):
    r"""
    MEDfileCommentRd(fid) -> med_err

    Parameters
    ----------
    fid: med_idt const

    """
    return _medfile.MEDfileCommentRd(fid)

def MEDfileCompatibility(filename):
    r"""
    MEDfileCompatibility(filename) -> med_err

    Parameters
    ----------
    filename: char const *const

    """
    return _medfile.MEDfileCompatibility(filename)

def MEDfileNumVersionRd(fid):
    r"""
    MEDfileNumVersionRd(fid) -> med_err

    Parameters
    ----------
    fid: med_idt const

    """
    return _medfile.MEDfileNumVersionRd(fid)

def MEDfileStrVersionRd(fid):
    r"""
    MEDfileStrVersionRd(fid) -> med_err

    Parameters
    ----------
    fid: med_idt const

    """
    return _medfile.MEDfileStrVersionRd(fid)

def MEDfileObjectsMount(fid, filename, medclass):
    r"""
    MEDfileObjectsMount(fid, filename, medclass) -> med_idt

    Parameters
    ----------
    fid: med_idt const
    filename: char const *const
    medclass: enum med_class const

    """
    return _medfile.MEDfileObjectsMount(fid, filename, medclass)

def MEDfileObjectsMountById(fid, chfid, chpath, medclass):
    r"""
    MEDfileObjectsMountById(fid, chfid, chpath, medclass) -> med_idt

    Parameters
    ----------
    fid: med_idt const
    chfid: med_idt const
    chpath: char const *const
    medclass: enum med_class const

    """
    return _medfile.MEDfileObjectsMountById(fid, chfid, chpath, medclass)

def MEDfileObjectsUnmount(fid, mid, medclass):
    r"""
    MEDfileObjectsUnmount(fid, mid, medclass) -> med_err

    Parameters
    ----------
    fid: med_idt const
    mid: med_idt const
    medclass: enum med_class const

    """
    return _medfile.MEDfileObjectsUnmount(fid, mid, medclass)

def MEDfileObjectExist(fid, medclass, objectname):
    r"""
    MEDfileObjectExist(fid, medclass, objectname) -> med_err

    Parameters
    ----------
    fid: med_idt const
    medclass: enum med_class const
    objectname: char const *const

    """
    return _medfile.MEDfileObjectExist(fid, medclass, objectname)

